==> fx-onscreen-keyboard-8.2.5-sources.jar: org/comtel2000/keyboard/control/StandardKeyCode.java <==
/*******************************************************************************
 * Copyright (c) 2017 comtel2000
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other materials provided with
 * the distribution.
 *
 * 3. Neither the name of the comtel2000 nor the names of its contributors may be used to endorse or
 * promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
 * WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

package org.comtel2000.keyboard.control;

public interface StandardKeyCode {

  int SHIFT_DOWN = -1;

  int SYMBOL_DOWN = -2;

  int CLOSE = -3;

  int TAB = -4;

  int BACK_SPACE = -5;

  int CTRL_DOWN = -6;

  int LOCALE_SWITCH = -7;

  int DELETE = -8;

  int ENTER = -9;

  int ARROW_UP = -10;

  int ARROW_DOWN = -11;

  int ARROW_LEFT = -12;

  int ARROW_RIGHT = -13;

  int UNDO = -14;

  int REDO = -15;

  int NUMERIC_TYPE = -16;

  int EMAIL_TYPE = -17;

  int URL_TYPE = -18;

  int CAPS_LOCK = -19;

  int HOME = -20;

  int END = -21;

  int PAGE_UP = -22;

  int PAGE_DOWN = -23;

  int HELP = -24;

  int PRINTSCREEN = -25;

  int F1 = -112;

  int F2 = -113;

  int F3 = -114;

  int F4 = -115;

  int F5 = -116;

  int F6 = -117;

  int F7 = -118;

  int F8 = -119;

  int F9 = -120;

  int F10 = -121;

  int F11 = -122;

  int F12 = -123;

}

==> fx-onscreen-keyboard-11.0.1-sources.jar: org/comtel2000/keyboard/control/StandardKeyCode.java <==
/*******************************************************************************
 * Copyright (c) 2017 comtel2000
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other materials provided with
 * the distribution.
 *
 * 3. Neither the name of the comtel2000 nor the names of its contributors may be used to endorse or
 * promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
 * WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

package org.comtel2000.keyboard.control;

interface StandardKeyCode {

  int SHIFT_DOWN = -1;

  int SYMBOL_DOWN = -2;

  int CLOSE = -3;

  int TAB = -4;

  int BACK_SPACE = -5;

  int CTRL_DOWN = -6;

  int LOCALE_SWITCH = -7;

  int DELETE = -8;

  int ENTER = -9;

  int ARROW_UP = -10;

  int ARROW_DOWN = -11;

  int ARROW_LEFT = -12;

  int ARROW_RIGHT = -13;

  int UNDO = -14;

  int REDO = -15;

  int NUMERIC_TYPE = -16;

  int EMAIL_TYPE = -17;

  int URL_TYPE = -18;

  int CAPS_LOCK = -19;

  int HOME = -20;

  int END = -21;

  int PAGE_UP = -22;

  int PAGE_DOWN = -23;

  int HELP = -24;

  int PRINTSCREEN = -25;

  int F1 = -112;

  int F2 = -113;

  int F3 = -114;

  int F4 = -115;

  int F5 = -116;

  int F6 = -117;

  int F7 = -118;

  int F8 = -119;

  int F9 = -120;

  int F10 = -121;

  int F11 = -122;

  int F12 = -123;

}
